@@ -28,7 +28,8 @@ Settings = NestedDict({
     'themes': {
         'bootstrap': "https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css",
         'highlight_js': "https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.4.0/styles/default.min.css",
-        'theme': "light"
+        'theme': "light",
+        'theme-opposite': None
     },
     'brand': {
         'app_name': "My App",
@@ -89,12 +90,15 @@ def setup_settings(config_path: Path):
     try:
         config = loads(config_path.read_text(encoding='utf-8'))
         validate(instance=config, schema=schema)
-        Settings.update(NestedDict(config))
-        Settings['out_dir'] = Path(Settings['paths', 'out'])
-        Settings['content_dir'] = Path(Settings['paths', 'content'])
-        Settings['url_prefix'] = getenv("URL_PREFIX", "")
-        Settings['config_path'] = config_path
-        Logger.update_level_from_string(Settings['log_level'])
+        new_config = Settings.copy()
+        new_config.update(NestedDict(config))
+        new_config['out_dir'] = Path(new_config['paths', 'out'])
+        new_config['content_dir'] = Path(new_config['paths', 'content'])
+        new_config['url_prefix'] = getenv("URL_PREFIX", "")
+        new_config['config_path'] = config_path
+        new_config['themes', 'theme-opposite'] = "light" if new_config['themes', 'theme'] == 'dark' else "dark"
+        Logger.update_level_from_string(new_config['log_level'])
+        return new_config
     except FileNotFoundError:
         Logger.log_error(f"Can't find config file: `{config_path.as_posix()}`")
     except JSONDecodeError as e:
