@@ -1,17 +1,18 @@
 import sys
 from pathlib import Path
+from textwrap import dedent
 
 from menagerie.generate import generate
 from menagerie.new_project import new_project
 
-__version__ = '0.1.0'
-__help__ = """
+__version__ = '0.1.1'
+__help__ =  dedent("""
                 Usage:
                     menagerie new-project [name] : Creates a new menagerie project with a given name
                     menagerie generate [config] : Generates a site with the given config
                     menagerie help : Shows this message
                     menagerie version : Shows the version
-            """
+            """)
 
 
 def execute_from_commandline(args: list[str] = None):
