@@ -4,7 +4,7 @@ from pathlib import Path
 from menagerie.Items.Managers.MetaManager import MetaManager
 from menagerie.Items.Managers.PageManager import PageManager
 from menagerie.Items.Managers.StaticManager import StaticManager
-from menagerie.Settings import setup_settings, Settings
+from menagerie.Settings import setup_settings
 from menagerie.SiteGen import SiteGen
 from menagerie.utils.logger import Logger
 
@@ -15,10 +15,10 @@ __all__ = (
 
 def generate(config_path: Path):
     Logger.log_info("Loading Config")
-    setup_settings(config_path)
+    config = setup_settings(config_path)
     managers = (PageManager, StaticManager, MetaManager)
     Logger.log_info("Setting Up")
-    gen = SiteGen(Settings, managers)
+    gen = SiteGen(config, managers)
     Logger.log_info("Beginning Generation")
     Logger.log_info("Finding Content")
     gen.find()
